| nipals | R Documentation |
Nipals to compute the first score and loading vectors of a matrix.
nipals(X, tol = 1e-6, maxit = 100)
X |
Datamatrix ( |
tol |
Tolerance for testing convergence of the NIPALS iterations for each PC. |
maxit |
Maximum number of NIPALS iterations for each PC. |
u |
left singular vector (u * sv = scores). |
v |
right singular vector (loadings). |
sv |
singular value. |
K.R. Gabriel, S. Zamir, Lower rank approximation of matrices by least squares with any choice of weights, Technometrics 21 (1979) 489–498.
n <- 8 ; p <- 6
X <- matrix(rnorm(n * p, mean = 10), ncol = p, byrow = TRUE)
nipals(X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.